@@ -81,7 +81,19 @@ class RequestError(Exception):
         return self.message
 
 
-class YandexDefaultException(Exception):
+class TooManyRequests(Exception):
+    """
+    exception thrown if an error occured during the request call, e.g a connection problem.
+    """
+
+    def __init__(self, message="Server Error: You made too many requests to the server. According to google, you are allowed to make 5 requests per second and up to 200k requests per day. You can wait and try again later or you can try the translate_batch function"):
+        self.message = message
+
+    def __str__(self):
+        return self.message
+
+
+class ServerException(Exception):
     """
     Default YandexTranslate exception from the official website
     """
@@ -97,5 +109,5 @@ class YandexDefaultException(Exception):
     }
 
     def __init__(self, status_code, *args):
-        message = self.errors.get(status_code)
-        super(YandexDefaultException, self).__init__(message, *args)
+        message = self.errors.get(status_code, "API server error")
+        super(ServerException, self).__init__(message, *args)
