@@ -8,7 +8,8 @@ from deep_translator.exceptions import (LanguageNotSupportedException,
                                         TranslationNotFound,
                                         NotValidPayload,
                                         ElementNotFoundInGetRequest,
-                                        RequestError)
+                                        RequestError,
+                                        TooManyRequests)
 from deep_translator.parent import BaseTranslator
 from requests.utils import requote_uri
 
@@ -87,6 +88,9 @@ class PonsTranslator(BaseTranslator):
             url = requote_uri(url)
             response = requests.get(url)
 
+            if response.status_code == 429:
+                raise TooManyRequests()
+
             if response.status_code != 200:
                 raise RequestError()
 
